@@ -71,7 +71,7 @@ def Shap_RFE_full(
     if (algo_type == "regression") and (str(cv_type.__class__()).startswith("StratifiedKFold")):
             raise ValueError("Fold Cross Validation uncorrect for regression algorithm, use KFold() or GroupKFold()")
             
-    if cv_scoring = "auto":
+    if cv_scoring == "auto":
         if algo_type == "classification":
             cv_scoring="roc_auc"
         elif algo_type == "regression":
